---
comments: true
---

# ArkLauncher

A GUI Launcher with update system, designed for Artistic Network.

* 📦 Framework: `maliang`
* ✏️ Author: <https://github.com/the-OmegaLabs>
* 🚀 GitHub: <https://github.com/the-OmegaLabs/ArkLauncher>

![Watchers](https://img.shields.io/github/watchers/the-OmegaLabs/ArkLauncher?label=Watchers&logo=github&style=flat "Watchers")
![Forks](https://img.shields.io/github/forks/the-OmegaLabs/ArkLauncher?label=Forks&logo=github&style=flat "Forks")
![Stars](https://img.shields.io/github/stars/the-OmegaLabs/ArkLauncher?label=Stars&color=gold&logo=github&style=flat "Stars")
![Issues](https://img.shields.io/github/issues/the-OmegaLabs/ArkLauncher?label=Issues&logo=github&style=flat "Issues")
![Pull Requests](https://img.shields.io/github/issues-pr/the-OmegaLabs/ArkLauncher?label=Pull%20Requests&logo=github&style=flat "Pull Requests")
![Discussions](https://img.shields.io/github/discussions/the-OmegaLabs/ArkLauncher?label=Discussions&logo=github&style=flat "Discussions")

![light](https://github.com/the-OmegaLabs/ArkLauncher/blob/main/preview/preview-en-light.png?raw=true#only-light)
![dark](https://github.com/the-OmegaLabs/ArkLauncher/blob/main/preview/preview-en-dark.png?raw=true#only-dark)
